### Encoding: latin1

### Name: igt
### Title: The Inverse Gaussian Type Distribution (IGTD)
### Aliases: digt pigt qigt rigt
### Keywords: distribution

### ** Examples

## Computes the pdf of the IGTD with g = "normal" for a vector x with mu = 1.0, 
## lambda = 1.0
x  <- seq(0.01, 4, by = 0.01)
fx <- digt(x, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
print(fx)

## At the end there is a graph of this pdf
plot(x, fx, main = "pdf of the IGTD (classical case)", ylab = "f(x)")

## Computes the cdf of the IGTD with g = "normal" for a vector x with mu = 1.0, 
## lambda = 1.0
Fx <- pigt(x, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
print(Fx)

## At the end there is a graph of this cdf
plot(x, Fx, main = "cdf of the IGTD (classical case)", ylab = "F(x)")

## Compute the 50 percentile (median) for a vector of probabilities x
## of the IGT with mu = 1.0, lambda = 1.0 and kernel = "normal"
q <- qigt(0.5, mu = 1.0, lambda = 1.0, kernel = "normal")
q

## Generates a sample x from the IGTD with normal kernel. 
## At the end we have the histogram of x
x <- rigt(1000, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
hist(x, main = "Histogram of a sample from IGTD")



